pub(super) fn wrap_index(logical_index: usize, capacity: usize) -> WrappedIndexExpand description
Returns the index in the underlying buffer for a given logical element index.
pub(super) fn wrap_index(logical_index: usize, capacity: usize) -> WrappedIndexReturns the index in the underlying buffer for a given logical element index.