#[repr(transparent)]pub(super) struct WrappedIndex(usize);Expand description
Represents an index that can be safely used to index the VecDeque buffer. It exists as a separate type to avoid passing logical (unwrapped) indices to various VecDeque functions by accident.
The invariant of this index is that it is always < VecDeque capacity, unless the VecDeque is empty (in that case the index can be 0 when the capacity is 0).
Tuple Fields
0: usizeImplementations
Sourceimpl WrappedIndex
impl WrappedIndex
Sourcepub(super) fn from_arbitrary_number(index: usize) -> Self
pub(super) fn from_arbitrary_number(index: usize) -> Self
The newly constructed index has to be in-bounds for the VecDeque that uses the index.
Sourcepub(super) unsafe fn add(self, offset: usize) -> Self
pub(super) unsafe fn add(self, offset: usize) -> Self
Safety invariant: the newly constructed index must still be in-bounds for the VecDeque
Sourcepub(super) unsafe fn sub(self, offset: usize) -> Self
pub(super) unsafe fn sub(self, offset: usize) -> Self
Safety invariant: the newly constructed index must still be in-bounds for the VecDeque
pub(super) const fn zero() -> Self
pub(super) fn abs_diff(self, other: Self) -> usize
pub(super) fn as_index(self) -> usize
pub(super) fn is_zero(self) -> bool